# Trinsic-Api
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v1
- Package version: 0.3.1
- Generator version: 7.8.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import trinsic_api
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import trinsic_api
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import trinsic_api
from trinsic_api.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.trinsic.id
# See configuration.py for a list of all supported configuration parameters.
configuration = trinsic_api.Configuration(
    host = "https://api.trinsic.id"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization: Bearer
configuration = trinsic_api.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
with trinsic_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = trinsic_api.AttachmentsApi(api_client)
    get_attachment_request = trinsic_api.GetAttachmentRequest() # GetAttachmentRequest |  (optional)

    try:
        # Get Attachment
        api_instance.get_attachment(get_attachment_request=get_attachment_request)
    except ApiException as e:
        print("Exception when calling AttachmentsApi->get_attachment: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.trinsic.id*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AttachmentsApi* | [**get_attachment**](docs/AttachmentsApi.md#get_attachment) | **POST** /api/v1/attachments/attachment | Get Attachment
*NetworkApi* | [**identity_lookup**](docs/NetworkApi.md#identity_lookup) | **GET** /api/v1/network/identities/{phoneNumber} | Lookup Identity
*NetworkApi* | [**list_providers**](docs/NetworkApi.md#list_providers) | **GET** /api/v1/network/providers | List Identity Providers
*SessionsApi* | [**cancel_session**](docs/SessionsApi.md#cancel_session) | **POST** /api/v1/sessions/{sessionId}/cancel | Cancel Session
*SessionsApi* | [**create_session**](docs/SessionsApi.md#create_session) | **POST** /api/v1/sessions | Create Session
*SessionsApi* | [**get_session**](docs/SessionsApi.md#get_session) | **GET** /api/v1/sessions/{sessionId} | Get Session
*SessionsApi* | [**get_session_result**](docs/SessionsApi.md#get_session_result) | **POST** /api/v1/sessions/{sessionId}/results | Get Session Results
*SessionsApi* | [**list_sessions**](docs/SessionsApi.md#list_sessions) | **GET** /api/v1/sessions | List Sessions
*SessionsApi* | [**redact_session**](docs/SessionsApi.md#redact_session) | **POST** /api/v1/sessions/{sessionId}/redact | Redact Session


## Documentation For Models

 - [Address](docs/Address.md)
 - [Attachments](docs/Attachments.md)
 - [CancelSessionResponse](docs/CancelSessionResponse.md)
 - [CreateSessionRequest](docs/CreateSessionRequest.md)
 - [CreateSessionResponse](docs/CreateSessionResponse.md)
 - [DisclosedFields](docs/DisclosedFields.md)
 - [DisclosedFieldsRequest](docs/DisclosedFieldsRequest.md)
 - [DocumentData](docs/DocumentData.md)
 - [FailureMessage](docs/FailureMessage.md)
 - [GetAttachmentRequest](docs/GetAttachmentRequest.md)
 - [GetSessionResponse](docs/GetSessionResponse.md)
 - [GetSessionResultRequest](docs/GetSessionResultRequest.md)
 - [GetSessionResultResponse](docs/GetSessionResultResponse.md)
 - [IdentityData](docs/IdentityData.md)
 - [IdentityLookupResponse](docs/IdentityLookupResponse.md)
 - [ListProvidersResponse](docs/ListProvidersResponse.md)
 - [ListSessionsResponse](docs/ListSessionsResponse.md)
 - [OrderDirection](docs/OrderDirection.md)
 - [PersonData](docs/PersonData.md)
 - [ProviderInfo](docs/ProviderInfo.md)
 - [Session](docs/Session.md)
 - [SessionFailCode](docs/SessionFailCode.md)
 - [SessionOrdering](docs/SessionOrdering.md)
 - [SessionState](docs/SessionState.md)
 - [ValidationResult](docs/ValidationResult.md)
 - [Verification](docs/Verification.md)
 - [VerificationFailCode](docs/VerificationFailCode.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="Bearer"></a>
### Bearer

- **Type**: Bearer authentication


## Author




